@@ -36,7 +36,7 @@ class Rabi(PulsedSim):
     """
 
     def __init__(
-        self, pulse_duration, system, H1, H2=None, pulse_shape=square_pulse, pulse_params=None, options=None
+        self, pulse_duration, system, h1, H2=None, pulse_shape=square_pulse, pulse_params=None, options=None
     ):
         """
         Constructor for the Rabi pulsed experiment class.
@@ -47,12 +47,12 @@ class Rabi(PulsedSim):
             Time array for the simulation representing the pulse duration to be used as the variable for the simulation.
         system : QSys
             Quantum system object containing the initial state, internal Hamiltonian and collapse operators.
-        H1 : Qobj or list(Qobj)
+        h1 : Qobj or list(Qobj)
             Control Hamiltonian of the system.
         H2 : Qobj or list(Qobj)
             Time-dependent sensing Hamiltonian of the system.
         pulse_shape : FunctionType or list(FunctionType)
-            Pulse shape function or list of pulse shape functions representing the time modulation of H1.
+            Pulse shape function or list of pulse shape functions representing the time modulation of h1.
         pulse_params : dict
             Dictionary of parameters for the pulse_shape functions.
         options : dict
@@ -60,7 +60,7 @@ class Rabi(PulsedSim):
         """
         super().__init__(system, H2)
         self._check_attr_predef_seqs(
-            H1, pulse_shape, pulse_params, options, len(pulse_duration), None, None, None, None
+            h1, None, None, pulse_shape, pulse_params, options, len(pulse_duration), None, None, None, None
         )
 
         # check whether pulse_duration is a numpy array and if it is, assign it to the object
@@ -75,12 +75,7 @@ class Rabi(PulsedSim):
             self.variable = pulse_duration
             self.variable_name = f"Pulse Duration (1/{self.system.units_H0})"
 
-        if isinstance(H1, Qobj):
-            self.pulse_profiles = [[H1, pulse_duration, pulse_shape, self.pulse_params]]
-        else:
-            self.pulse_profiles = [
-                [H1[i], pulse_duration, pulse_shape[i], self.pulse_params] for i in range(len(H1))
-            ]
+        self._append_pulse_to_profile(0, self.total_time)
 
     def run(self):
         """
@@ -129,8 +124,6 @@ class PMR(PulsedSim):
     ----------
     frequencies : numpy.ndarray
         Array of frequencies to run the simulation.
-    pulse_duration : float or int
-        Duration of the pulse.
 
     Methods
     -------
@@ -150,7 +143,7 @@ class PMR(PulsedSim):
         frequencies,
         system,
         pulse_duration,
-        H1,
+        h1,
         H2=None,
         pulse_shape=square_pulse,
         pulse_params=None,
@@ -168,12 +161,12 @@ class PMR(PulsedSim):
             Quantum system object containing the initial state, internal Hamiltonian and collapse operators.
         pulse_duration : float or int
             Duration of the pulse.
-        H1 : Qobj or list(Qobj)
+        h1 : Qobj or list(Qobj)
             Control Hamiltonian of the system.
         H2 : Qobj or list(Qobj)
             Time-dependent sensing Hamiltonian of the system.
         pulse_shape : FunctionType or list(FunctionType)
-            Pulse shape function or list of pulse shape functions representing the time modulation of H1.
+            Pulse shape function or list of pulse shape functions representing the time modulation of h1.
         pulse_params : dict
             Dictionary of parameters for the pulse_shape functions.
         time_steps : int
@@ -183,7 +176,7 @@ class PMR(PulsedSim):
         """
         super().__init__(system, H2)
         self._check_attr_predef_seqs(
-            H1, pulse_shape, pulse_params, options, time_steps, None, None, None, None
+            h1, None, None, pulse_shape, pulse_params, options, time_steps, None, None, None, None
         )
 
         # check whether frequencies is a numpy array or list and if it is, assign it to the object
@@ -201,10 +194,11 @@ class PMR(PulsedSim):
         if not isinstance(pulse_duration, (float, int)) or pulse_duration <= 0:
             raise ValueError("pulse_duration must be a positive real number")
         else:
-            self.pulse_duration = pulse_duration
+            self.total_time = pulse_duration
 
         # set the sequence attribute to the PMR_sequence method
         self.sequence = self.PMR_sequence
+        self._append_pulse_to_profile(0, self.total_time)
 
     def PMR_sequence(self, f):
         """
@@ -223,7 +217,7 @@ class PMR(PulsedSim):
         """
         self.pulse_params["f_pulse"] = f
 
-        self._pulse(self.Ht, self.pulse_duration, self.options, self.pulse_params)
+        self._pulse(self.Ht, self.total_time, self.options, self.pulse_params)
 
         return self.rho
 
@@ -247,8 +241,6 @@ class PMR(PulsedSim):
         else:
             raise ValueError("f_pulse must be a float or an integer")
 
-        self.total_time = self.pulse_duration
-
         super().plot_pulses(figsize, xlabel, ylabel, title)
 
 
@@ -284,7 +276,8 @@ class Ramsey(PulsedSim):
         free_duration,
         system,
         pi_pulse_duration,
-        H1,
+        h1=None,
+        Rx=None,
         H2=None,
         projection_pulse=True,
         pulse_shape=square_pulse,
@@ -301,8 +294,12 @@ class Ramsey(PulsedSim):
             Time array for the simulation representing the free evolution time to be used as the variable attribute for the simulation.
         system : QSys
             Quantum system object containing the initial state, internal Hamiltonian and collapse operators.
-        H1 : Qobj or list(Qobj)
+        pi_pulse_duration : float, int or 0
+            Duration of the pi pulse. If set to 0, the pulses are perfect delta pulses and the time-evolution is calculated with the rotation operator.
+        h1 : Qobj or list(Qobj)
             Control Hamiltonian of the system.
+        Rx : Qobj or None
+            Rotation operator around the x-axis, used only if the pi_pulse_duration is set to 0.
         pi_pulse_duration : float or int
             Duration of the pi pulse.
         H2 : Qobj or list(Qobj)
@@ -311,7 +308,7 @@ class Ramsey(PulsedSim):
             Boolean to determine if the measurement is to be performed in the Sz basis or not.
             If True, a final pi/2 pulse is included in order to project the result into the Sz basis, as for most color centers.
         pulse_shape : FunctionType or list(FunctionType)
-            Pulse shape function or list of pulse shape functions representing the time modulation of H1.
+            Pulse shape function or list of pulse shape functions representing the time modulation of h1.
         pulse_params : dict
             Dictionary of parameters for the pulse_shape functions.
         time_steps : int
@@ -321,7 +318,9 @@ class Ramsey(PulsedSim):
         """
         super().__init__(system, H2)
         self._check_attr_predef_seqs(
-            H1,
+            h1,
+            Rx,
+            Rx,
             pulse_shape,
             pulse_params,
             options,
@@ -338,6 +337,7 @@ class Ramsey(PulsedSim):
         Defines the Ramsey sequence for a given free evolution time tau and the set of attributes defined in the constructor.
         The sequence consists of an initial pi/2 pulse and a single free evolution.
         If the projection_pulse is set to True, a final pi/2 pulse is included in order to project the result into the Sz basis.
+        If the pi_pulse_duration is set to 0, the pulses are perfect delta pulses and the time-evolution is calculated with the rotation operator.
         The sequence is to be called by the parallel_map method of QuTip.
 
         Parameters
@@ -350,12 +350,19 @@ class Ramsey(PulsedSim):
         rho : Qobj
             Final state.
         """
+        if self.pi_pulse_duration == 0:
+            self._delta_pulse(self.Rx_half)
+            self._free_evolution(tau, self.options)
 
-        self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
-        self._free_evolution(tau - self.pi_pulse_duration / 2, self.options)
+            if self.projection_pulse:
+                self._delta_pulse(self.Rx_half)
 
-        if self.projection_pulse:
+        else:
             self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
+            self._free_evolution(tau - self.pi_pulse_duration / 2, self.options)
+
+            if self.projection_pulse:
+                self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
 
         return self.rho
 
@@ -377,96 +384,15 @@ class Ramsey(PulsedSim):
 
         self.pulse_profiles = []
 
-        # if projection_pulse is True, include the final pi/2 pulse in the pulse_profiles
+        self._append_pulse_to_profile(0, self.pi_pulse_duration / 2)
+        t0 = self.pi_pulse_duration / 2
+
+        self.pulse_profiles.append(["free_evo", [t0, t0 + tau], None, None])
+        t0 += tau
+
         if self.projection_pulse:
-            ps = tau - self.pi_pulse_duration
-
-            # if only one control Hamiltonian is given, append the pulse_profiles with the Ramsey sequence
-            if isinstance(self.H1, Qobj):
-                self.pulse_profiles.append(
-                    [
-                        self.H1,
-                        np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                        self.pulse_shape,
-                        self.pulse_params,
-                    ]
-                )
-                t0 = self.pi_pulse_duration / 2
-                self.pulse_profiles.append([None, [t0, ps + t0], None, None])
-                t0 += ps
-                self.pulse_profiles.append(
-                    [
-                        self.H1,
-                        np.linspace(t0, t0 + self.pi_pulse_duration / 2, self.time_steps),
-                        self.pulse_shape,
-                        self.pulse_params,
-                    ]
-                )
-                t0 += self.pi_pulse_duration / 2
-
-            # otherwise if a list of control Hamiltonians is given, it sums over all H1 and appends to the pulse_profiles
-            elif isinstance(self.H1, list):
-                self.pulse_profiles.append(
-                    [
-                        [
-                            self.H1[i],
-                            np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                            self.pulse_shape[i],
-                            self.pulse_params,
-                        ]
-                        for i in range(len(self.H1))
-                    ]
-                )
-                t0 = self.pi_pulse_duration / 2
-                self.pulse_profiles.append([None, [t0, ps + t0], None, None])
-                t0 += ps
-                self.pulse_profiles.append(
-                    [
-                        [
-                            self.H1[i],
-                            np.linspace(t0, t0 + self.pi_pulse_duration / 2, self.time_steps),
-                            self.pulse_shape[i],
-                            self.pulse_params,
-                        ]
-                        for i in range(len(self.H1))
-                    ]
-                )
-                t0 += self.pi_pulse_duration / 2
-
-        # if projection_pulse is false, do not include the final pi/2 pulse in the pulse_profiles
-        else:
-            ps = tau - self.pi_pulse_duration / 2
-
-            # if only one control Hamiltonian is given, append the pulse_profiles with the Ramsey sequence
-            if isinstance(self.H1, Qobj):
-                self.pulse_profiles.append(
-                    [
-                        self.H1,
-                        np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                        self.pulse_shape,
-                        self.pulse_params,
-                    ]
-                )
-                t0 = self.pi_pulse_duration / 2
-                self.pulse_profiles.append([None, [t0, ps + t0], None, None])
-                t0 += ps
-
-            # otherwise if a list of control Hamiltonians is given, it sums over all H1 and appends to the pulse_profiles
-            elif isinstance(self.H1, list):
-                self.pulse_profiles.append(
-                    [
-                        [
-                            self.H1[i],
-                            np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                            self.pulse_shape[i],
-                            self.pulse_params,
-                        ]
-                        for i in range(len(self.H1))
-                    ]
-                )
-                t0 = self.pi_pulse_duration / 2
-                self.pulse_profiles.append([None, [t0, ps + t0], None, None])
-                t0 += ps
+            self._append_pulse_to_profile(t0, self.pi_pulse_duration / 2)
+            t0 += self.pi_pulse_duration / 2
 
         self.total_time = t0
 
@@ -532,7 +458,8 @@ class Hahn(PulsedSim):
         free_duration,
         system,
         pi_pulse_duration,
-        H1,
+        h1=None,
+        Rx=None,
         H2=None,
         projection_pulse=True,
         pulse_shape=square_pulse,
@@ -549,17 +476,19 @@ class Hahn(PulsedSim):
             Time array for the simulation representing the free evolution time to be used as the variable attribute for the simulation.
         system : QSys
             Quantum system object containing the initial state, internal Hamiltonian and collapse operators.
-        H1 : Qobj or list of Qobj
+        pi_pulse_duration : float, int or 0
+            Duration of the pi pulse. If set to 0, the pulses are perfect delta pulses and the time-evolution is calculated with the rotation operator.
+        h1 : Qobj or list of Qobj
             Control Hamiltonian of the system.
-        pi_pulse_duration : float or int
-            Duration of the pi pulse.
+        Rx : Qobj or None
+            Rotation operator around the x-axis, used only if the pi_pulse_duration is set to 0.
         H2 : Qobj or list of Qobj
             Time dependent sensing Hamiltonian of the system.
         projection_pulse : bool
             Boolean to determine if the measurement is to be performed in the Sz basis or not.
             If True, a final pi/2 pulse is included in order to project the result into the Sz basis, as done for the most color centers.
         pulse_shape : FunctionType or list of FunctionType
-            Pulse shape function or list of pulse shape functions representing the time modulation of H1.
+            Pulse shape function or list of pulse shape functions representing the time modulation of h1.
         pulse_params : dict
             Dictionary of parameters for the pulse_shape functions.
         time_steps : int
@@ -569,7 +498,9 @@ class Hahn(PulsedSim):
         """
         super().__init__(system, H2)
         self._check_attr_predef_seqs(
-            H1,
+            h1,
+            Rx,
+            Rx,
             pulse_shape,
             pulse_params,
             options,
@@ -584,8 +515,8 @@ class Hahn(PulsedSim):
     def hahn_sequence(self, tau):
         """
         Defines the Hahn echo sequence for a given free evolution time tau and the set of attributes defined in the constructor.
-
         The sequence consists of a pi/2 pulse, a free evolution time tau, a pi pulse and another free evolution time tau followed by a pi/2 pulse, if the projection pulse is set to True.
+        If the pi_pulse_duration is set to 0, the pulses are perfect delta pulses and the time-evolution is calculated with the rotation operator.
         The sequence is to be called by the parallel_map method of QuTip.
 
         Parameters
@@ -598,18 +529,29 @@ class Hahn(PulsedSim):
         rho : Qobj
             Final state.
         """
-        # pulse separation time
-        ps = tau - self.pi_pulse_duration
+        # if pi_pulse_duration is 0, use the delta pulse method
+        if self.pi_pulse_duration == 0:
+            self._delta_pulse(self.Rx_half)
+            self._free_evolution(tau, self.options)
+            self._delta_pulse(self.Rx)
+            self._free_evolution(tau, self.options)
 
-        self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
-        self._free_evolution(ps, self.options)
-        self._pulse(self.Ht, self.pi_pulse_duration, self.options, self.pulse_params)
+            if self.projection_pulse:
+                self._delta_pulse(self.Rx_half)
 
-        if self.projection_pulse:
-            self._free_evolution(ps, self.options)
-            self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
         else:
-            self._free_evolution(ps + self.pi_pulse_duration / 2, self.options)
+            # pulse separation time
+            ps = tau - self.pi_pulse_duration
+
+            self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
+            self._free_evolution(ps, self.options)
+            self._pulse(self.Ht, self.pi_pulse_duration, self.options, self.pulse_params)
+
+            if self.projection_pulse:
+                self._free_evolution(ps, self.options)
+                self._pulse(self.Ht, self.pi_pulse_duration / 2, self.options, self.pulse_params)
+            else:
+                self._free_evolution(ps + self.pi_pulse_duration / 2, self.options)
 
         return self.rho
 
@@ -630,143 +572,30 @@ class Hahn(PulsedSim):
             raise ValueError("tau must be a positive real number larger than pi_pulse_duration")
 
         self.pulse_profiles = []
+        ps = tau - self.pi_pulse_duration
+
+        # pi/2 pulse
+        self._append_pulse_to_profile(0, self.pi_pulse_duration / 2)
+        t0 = self.pi_pulse_duration / 2
+        # free evolution
+        self.pulse_profiles.append(["free_evo", [t0, t0 + ps], None, None])
+        t0 += ps
+        # pi pulse
+        self._append_pulse_to_profile(t0, self.pi_pulse_duration)
+        t0 += self.pi_pulse_duration
 
-        # if projection_pulse is True, include the final pi/2 pulse in the pulse_profiles
         if self.projection_pulse:
-            # if only one control Hamiltonian is given, append the pulse_profiles with the Hahn echo sequence as in the hahn_sequence method
-            if isinstance(self.H1, Qobj):
-                self.pulse_profiles.append(
-                    [
-                        self.H1,
-                        np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                        self.pulse_shape,
-                        self.pulse_params,
-                    ]
-                )
-                t0 = self.pi_pulse_duration / 2
-                self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration], None, None])
-                t0 += tau - self.pi_pulse_duration
-                self.pulse_profiles.append(
-                    [
-                        self.H1,
-                        np.linspace(t0, t0 + self.pi_pulse_duration, self.time_steps),
-                        self.pulse_shape,
-                        self.pulse_params,
-                    ]
-                )
-                t0 += self.pi_pulse_duration
-                self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration], None, None])
-                t0 += tau - self.pi_pulse_duration
-                self.pulse_profiles.append(
-                    [
-                        self.H1,
-                        np.linspace(t0, t0 + self.pi_pulse_duration / 2, self.time_steps),
-                        self.pulse_shape,
-                        self.pulse_params,
-                    ]
-                )
-                t0 += self.pi_pulse_duration / 2
+            # free evolution
+            self.pulse_profiles.append(["free_evo", [t0, t0 + ps], None, None])
+            t0 += ps
+            # pi/2 pulse
+            self._append_pulse_to_profile(t0, self.pi_pulse_duration / 2)
+            t0 += self.pi_pulse_duration / 2
+        else:
+            # free evolution
+            self.pulse_profiles.append(["free_evo", [t0, t0 + ps + self.pi_pulse_duration / 2], None, None])
+            t0 += ps + self.pi_pulse_duration / 2
 
-            # otherwise if a list of control Hamiltonians is given, it sums over all H1 and appends to the pulse_profiles the Hahn echo sequence as in the hahn_sequence method
-            elif isinstance(self.H1, list):
-                self.pulse_profiles.append(
-                    [
-                        [
-                            self.H1[i],
-                            np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                            self.pulse_shape[i],
-                            self.pulse_params,
-                        ]
-                        for i in range(len(self.H1))
-                    ]
-                )
-                t0 = self.pi_pulse_duration / 2
-                self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration], None, None])
-                t0 += tau - self.pi_pulse_duration
-                self.pulse_profiles.append(
-                    [
-                        [
-                            self.H1[i],
-                            np.linspace(t0, t0 + self.pi_pulse_duration, self.time_steps),
-                            self.pulse_shape[i],
-                            self.pulse_params,
-                        ]
-                        for i in range(len(self.H1))
-                    ]
-                )
-                t0 += self.pi_pulse_duration
-                self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration], None, None])
-                t0 += tau - self.pi_pulse_duration
-                self.pulse_profiles.append(
-                    [
-                        [
-                            self.H1[i],
-                            np.linspace(t0, t0 + self.pi_pulse_duration / 2, self.time_steps),
-                            self.pulse_shape[i],
-                            self.pulse_params,
-                        ]
-                        for i in range(len(self.H1))
-                    ]
-                )
-                t0 += self.pi_pulse_duration / 2
-
-        # if projection_pulse is False, do not include the final pi/2 pulse in the pulse_profiles
-        elif isinstance(self.H1, Qobj):
-            self.pulse_profiles.append(
-                [
-                    self.H1,
-                    np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                    self.pulse_shape,
-                    self.pulse_params,
-                ]
-            )
-            t0 = self.pi_pulse_duration / 2
-            self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration], None, None])
-            t0 += tau - self.pi_pulse_duration
-            self.pulse_profiles.append(
-                [
-                    self.H1,
-                    np.linspace(t0, t0 + self.pi_pulse_duration, self.time_steps),
-                    self.pulse_shape,
-                    self.pulse_params,
-                ]
-            )
-            t0 += self.pi_pulse_duration
-            self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration / 2], None, None])
-            t0 += tau - self.pi_pulse_duration / 2
-
-        # otherwise if a list of control Hamiltonians is given, it sums over all H1 and appends to the pulse_profiles the Hahn echo sequence as in the hahn_sequence method
-        elif isinstance(self.H1, list):
-            self.pulse_profiles.append(
-                [
-                    [
-                        self.H1[i],
-                        np.linspace(0, self.pi_pulse_duration / 2, self.time_steps),
-                        self.pulse_shape[i],
-                        self.pulse_params,
-                    ]
-                    for i in range(len(self.H1))
-                ]
-            )
-            t0 = self.pi_pulse_duration / 2
-            self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration], None, None])
-            t0 += tau - self.pi_pulse_duration
-            self.pulse_profiles.append(
-                [
-                    [
-                        self.H1[i],
-                        np.linspace(t0, t0 + self.pi_pulse_duration, self.time_steps),
-                        self.pulse_shape[i],
-                        self.pulse_params,
-                    ]
-                    for i in range(len(self.H1))
-                ]
-            )
-            t0 += self.pi_pulse_duration
-            self.pulse_profiles.append([None, [t0, t0 + tau - self.pi_pulse_duration / 2], None, None])
-            t0 += tau - self.pi_pulse_duration / 2
-
-        # set the total_time attribute to the total time of the pulse sequence
         self.total_time = t0
 
     def plot_pulses(
