@@ -36,7 +36,7 @@ class PulsedSim:
     variable_name : str
         Name of the variable
     pulse_profiles :list
-        List of pulse profiles for plotting purposes, where each element is a list [H1, tarray, pulse_shape, pulse_params]
+        List of pulse profiles for plotting purposes, where each element is a list [h1, tarray, pulse_shape, pulse_params]
     results : list
         Results of the experiment to be later generated in the run method
     sequence : callable
@@ -52,15 +52,15 @@ class PulsedSim:
     free_duration : np.array
         Free evolution times of the sequence, if applicable
     pulse_shape : callable or list(callable)
-        Pulse shape function or list of pulse shape functions representing the time modulation of H1
+        Pulse shape function or list of pulse shape functions representing the time modulation of h1
     pulse_params : dict
         Dictionary of parameters for the pulse_shape functions
     options : dict
         Options for the Qutip solver, such as 'nsteps', 'atol', 'rtol', 'order'
-    H1 : Qobj or list(Qobj)
+    h1 : Qobj or list(Qobj)
         Control Hamiltonian of the system, which can be a single Qobj or a list of Qobjs
     Ht : list
-        List of Hamiltonians for the pulse operation in the form [H0, [H1, pulse_shape], H2]
+        List of Hamiltonians for the pulse operation in the form [H0, [h1, pulse_shape], H2]
     time_steps : int
         Number of time steps for the pulses, if applicable
 
@@ -88,6 +88,8 @@ class PulsedSim:
         Plots the pulse profiles of the experiment by iterating over the pulse_profiles list and plotting each pulse profile and free evolution
     _check_attr_predef_seqs :
         Checks the common attributes of the PulsedSim object for the predefined sequences and sets them accordingly
+    _append_pulse_to_profiles :
+        Appends the pulse profile to the pulse_profiles list, which is used for plotting purposes.
     """
 
     def __init__(self, system, H2=None):
@@ -175,7 +177,6 @@ class PulsedSim:
                 self.rho,
                 2 * np.pi * np.linspace(self.total_time, self.total_time + duration, self.time_steps),
                 self.system.c_ops,
-                e_ops=[],
                 options=options,
             ).states[-1]
         elif self.rho.isket:
@@ -190,20 +191,20 @@ class PulsedSim:
         self.total_time += duration
 
     def add_pulse(
-        self, duration, H1, pulse_shape=square_pulse, pulse_params=None, time_steps=100, options=None
+        self, duration, h1, pulse_shape=square_pulse, pulse_params=None, time_steps=100, options=None
     ):
         """
         Perform variables checks and adds a pulse operation to the sequence of operations of the experiment for a given duration of the pulse,
-        control Hamiltonian H1, pulse phase, pulse shape function, pulse parameters and time steps by calling the pulse method.
+        control Hamiltonian h1, pulse phase, pulse shape function, pulse parameters and time steps by calling the pulse method.
 
         Parameters
         ----------
         duration : float or int
             Duration of the pulse
-        H1 : Qobj or list(Qobj)
+        h1 : Qobj or list(Qobj)
             Control Hamiltonian of the system
         pulse_shape : callable or list(callable)
-            Pulse shape function or list of pulse shape functions representing the time modulation of t H1
+            Pulse shape function or list of pulse shape functions representing the time modulation of t h1
         pulse_params : dict
             Dictionary of parameters for the pulse_shape functions
         time_steps : int
@@ -240,44 +241,44 @@ class PulsedSim:
         if "phi_t" not in pulse_params:
             pulse_params["phi_t"] = 0
 
-        # check if H1 is a Qobj or a list of Qobj with the same dimensions as H0
-        if isinstance(H1, Qobj) and H1.shape == self.system.H0.shape:
+        # check if h1 is a Qobj or a list of Qobj with the same dimensions as H0
+        if isinstance(h1, Qobj) and h1.shape == self.system.H0.shape:
             # append it to the pulse_profiles list
             self.pulse_profiles.append(
                 [
-                    H1,
+                    h1,
                     np.linspace(self.total_time, self.total_time + duration, self.time_steps),
                     pulse_shape,
                     pulse_params,
                 ]
             )
             if self.H2 is None:
-                Ht = [self.system.H0, [H1, pulse_shape]]
+                Ht = [self.system.H0, [h1, pulse_shape]]
             else:
-                Ht = [self.system.H0, [H1, pulse_shape], self.H2]
+                Ht = [self.system.H0, [h1, pulse_shape], self.H2]
 
         elif (
-            isinstance(H1, list)
-            and all(isinstance(op, Qobj) and op.shape == self.system.H0.shape for op in H1)
-            and len(H1) == len(pulse_shape)
+            isinstance(h1, list)
+            and all(isinstance(op, Qobj) and op.shape == self.system.H0.shape for op in h1)
+            and len(h1) == len(pulse_shape)
         ):
             self.pulse_profiles = [
                 [
-                    H1[i],
+                    h1[i],
                     np.linspace(self.total_time, self.total_time + duration, self.time_steps),
                     pulse_shape[i],
                     pulse_params,
                 ]
-                for i in range(len(H1))
+                for i in range(len(h1))
             ]
             if self.H2 is None:
-                Ht = [self.system.H0] + [[H1[i], pulse_shape[i]] for i in range(len(H1))]
+                Ht = [self.system.H0] + [[h1[i], pulse_shape[i]] for i in range(len(h1))]
             else:
-                Ht = [self.system.H0] + [[H1[i], pulse_shape[i]] for i in range(len(H1))] + self.H2
+                Ht = [self.system.H0] + [[h1[i], pulse_shape[i]] for i in range(len(h1))] + self.H2
 
         else:
             raise ValueError(
-                "H1 must be a Qobj or a list of Qobjs of the same shape as H0 and with the same length as the pulse_shape list"
+                "h1 must be a Qobj or a list of Qobjs of the same shape as H0 and with the same length as the pulse_shape list"
             )
 
         # add the pulse operation to the sequence of operations by calling the pulse method
@@ -293,7 +294,7 @@ class PulsedSim:
         Parameters
         ----------
         Ht : list
-            List of Hamiltonians for the pulse operation in the form [H0, [H1, pulse_shape]]
+            List of Hamiltonians for the pulse operation in the form [H0, [h1, pulse_shape]]
         tarray : np.array
             Time array for the pulse operation
         options : dict
@@ -307,7 +308,6 @@ class PulsedSim:
             self.rho,
             2 * np.pi * np.linspace(self.total_time, self.total_time + duration, self.time_steps),
             self.system.c_ops,
-            e_ops=[],
             options=options,
             args=core_pulse_params,
         ).states[-1]
@@ -379,7 +379,7 @@ class PulsedSim:
             self.results, self.rho = measurement.measure_observable(self.rho, self.system.observable, tol)
 
         else:
-            raise ValueError("observable must be a Qobj of the same shape as rho0, H0 and H1.")
+            raise ValueError("observable must be a Qobj of the same shape as rho0, H0 and h1.")
 
         return self.results.copy()
 
@@ -491,7 +491,7 @@ class PulsedSim:
         # iterate over all operations in the sequence
         for itr_pulses in range(len(self.pulse_profiles)):
             # if the pulse profile is a free evolution, plot a horizontal line at 0
-            if self.pulse_profiles[itr_pulses][0] is None:
+            if self.pulse_profiles[itr_pulses][0] == "free_evo":
                 ax.plot(
                     self.pulse_profiles[itr_pulses][1],
                     [0, 0],
@@ -501,32 +501,53 @@ class PulsedSim:
                     color="C0",
                 )
 
-            # if the pulse has operators, plot the pulse profiles
-            elif isinstance(self.pulse_profiles[itr_pulses][0], Qobj):
+            # if the pulse profile is a delta pulse, plot a vertical line at the time of the pulse
+            # check the correct label based on the phase of the pulse
+            elif self.pulse_profiles[itr_pulses][0] == "delta_pulse":
+                phase = self.pulse_profiles[itr_pulses][3]["phi_t"]
+                if phase == 0:
+                    label = "R_X"
+                elif phase == -np.pi / 2:
+                    label = "R_Y"
+                else:
+                    label = f"R_{phase}"
+
+                ax.axvline(
+                    self.pulse_profiles[itr_pulses][1],
+                    label=label,
+                    lw=3,
+                    alpha=0.7,
+                    color="C1",
+                )
+
+            # if the pulse is time dependent, plot the pulse profile
+            elif self.pulse_profiles[itr_pulses][0] == "pulse":
                 ax.plot(
                     self.pulse_profiles[itr_pulses][1],
                     self.pulse_profiles[itr_pulses][2](
                         2 * np.pi * self.pulse_profiles[itr_pulses][1], **self.pulse_profiles[itr_pulses][3]
                     ),
-                    label="H1",
+                    label="h1",
                     lw=2,
                     alpha=0.7,
                     color="C1",
                 )
 
+            # if the pulse has multiple operators, iterate over them
             elif isinstance(self.pulse_profiles[itr_pulses][0], list):
                 for itr_op in range(len(self.pulse_profiles[itr_pulses])):
-                    ax.plot(
-                        self.pulse_profiles[itr_pulses][itr_op][1],
-                        self.pulse_profiles[itr_pulses][itr_op][2](
-                            2 * np.pi * self.pulse_profiles[itr_pulses][itr_op][1],
-                            **self.pulse_profiles[itr_pulses][itr_op][3],
-                        ),
-                        label=f"H1_{itr_op}",
-                        lw=2,
-                        alpha=0.7,
-                        color=f"C{2 + itr_op}",
-                    )
+                    if self.pulse_profiles[itr_pulses][itr_op][0] == "pulse":
+                        ax.plot(
+                            self.pulse_profiles[itr_pulses][itr_op][1],
+                            self.pulse_profiles[itr_pulses][itr_op][2](
+                                2 * np.pi * self.pulse_profiles[itr_pulses][itr_op][1],
+                                **self.pulse_profiles[itr_pulses][itr_op][3],
+                            ),
+                            label=f"h1_{itr_op}",
+                            lw=2,
+                            alpha=0.7,
+                            color=f"C{2 + itr_op}",
+                        )
 
         ax.set_xlim(0, self.total_time)
         ax.set_xlabel(xlabel)
@@ -541,7 +562,9 @@ class PulsedSim:
 
     def _check_attr_predef_seqs(
         self,
-        H1,
+        h1,
+        Rx,
+        Ry,
         pulse_shape,
         pulse_params,
         options,
@@ -556,10 +579,10 @@ class PulsedSim:
 
         Parameters
         ----------
-        H1 : Qobj or list(Qobj)
+        h1 : Qobj or list(Qobj)
             Control Hamiltonian of the system
         pulse_shape : callable or list(callable)
-            Pulse shape function or list of pulse shape functions representing the time modulation of H1
+            Pulse shape function or list of pulse shape functions representing the time modulation of h1
         pulse_params : dict
             Dictionary of parameters for the pulse_shape functions
         options : dict
@@ -605,32 +628,6 @@ class PulsedSim:
         else:
             raise ValueError("options must be a dictionary of dynamic solver options from Qutip")
 
-        # check whether H1 is a Qobj or a list of Qobjs of the same shape as H0 and with the same length as the pulse_shape list and if it is, assign it to the object
-        if isinstance(H1, Qobj) and H1.shape == self.system.H0.shape:
-            self.H1 = H1
-            if self.H2 is None:
-                self.Ht = [self.system.H0, [H1, pulse_shape]]
-            else:
-                self.Ht = [self.system.H0, [H1, pulse_shape], self.H2]
-                self.H0_H2 = [self.system.H0, self.H2]
-
-        elif (
-            isinstance(H1, list)
-            and all(isinstance(op, Qobj) and op.shape == self.system.H0.shape for op in H1)
-            and len(H1) == len(pulse_shape)
-        ):
-            self.H1 = H1
-            if self.H2 is None:
-                self.Ht = [self.system.H0] + [[H1[i], pulse_shape[i]] for i in range(len(H1))]
-            else:
-                self.Ht = [self.system.H0] + [[H1[i], pulse_shape[i]] for i in range(len(H1))] + self.H2
-                self.H0_H2 = [self.system.H0, self.H2]
-
-        else:
-            raise ValueError(
-                "H1 must be a Qobj or a list of Qobjs of the same shape as H0 with the same length as the pulse_shape list"
-            )
-
         # check whether time_steps is a positive integer and if it is, assign it to the object
         if not isinstance(time_steps, int) or time_steps <= 0:
             raise ValueError("time_steps must be a positive integer")
@@ -655,7 +652,7 @@ class PulsedSim:
             pass
         elif (
             not isinstance(pi_pulse_duration, (int, float))
-            or pi_pulse_duration <= 0
+            or pi_pulse_duration < 0
             or pi_pulse_duration > free_duration[0]
         ):
             warnings.warn(
@@ -680,3 +677,85 @@ class PulsedSim:
             self.projection_pulse = projection_pulse
         else:
             raise ValueError("projection_pulse must be a boolean")
+
+        # if pi_pulse_duration is 0, check if Rx and Ry are correctly defined, otherwise check if h1 is correct
+        if pi_pulse_duration == 0:
+            # check whether Rx and Ry are Qobjs of the same shape as H0 and if they are, assign them to the object
+            if isinstance(Rx, Qobj) and Rx.shape == self.system.H0.shape:
+                self.Rx = Rx
+                self.Rx_half = Rx.sqrtm()
+            elif Rx is None:
+                raise ValueError("If pi_pulse_duration is 0, the rotation operator Rx must be provided")
+            else:
+                raise ValueError("Rx must be a Qobj of the same shape as H0")
+
+            if isinstance(Ry, Qobj) and Ry.shape == self.system.H0.shape:
+                self.Ry = Ry
+                self.Ry_half = Ry.sqrtm()
+            elif Ry is None:
+                raise ValueError("If pi_pulse_duration is 0, the rotation operator Ry must be provided")
+            else:
+                raise ValueError("Ry must be a Qobj of the same shape as H0")
+
+        else:
+            # check whether h1 is a Qobj or a list of Qobjs of the same shape as H0 and with the same length as the pulse_shape list and if it is, assign it to the object
+            if isinstance(h1, Qobj) and h1.shape == self.system.H0.shape:
+                self.h1 = h1
+                if self.H2 is None:
+                    self.Ht = [self.system.H0, [h1, pulse_shape]]
+                else:
+                    self.Ht = [self.system.H0, [h1, pulse_shape], self.H2]
+                    self.H0_H2 = [self.system.H0, self.H2]
+
+            elif (
+                isinstance(h1, list)
+                and all(isinstance(op, Qobj) and op.shape == self.system.H0.shape for op in h1)
+                and len(h1) == len(pulse_shape)
+            ):
+                self.h1 = h1
+                if self.H2 is None:
+                    self.Ht = [self.system.H0] + [[h1[i], pulse_shape[i]] for i in range(len(h1))]
+                else:
+                    self.Ht = [self.system.H0] + [[h1[i], pulse_shape[i]] for i in range(len(h1))] + self.H2
+                    self.H0_H2 = [self.system.H0, self.H2]
+
+            else:
+                raise ValueError(
+                    "h1 must be a Qobj or a list of Qobjs of the same shape as H0 with the same length as the pulse_shape list"
+                )
+
+    def _append_pulse_to_profile(self, t0, duration, pulse_params=None):
+        """
+        Internal method for appending a pulse to the pulse_profiles list to be called by _get_pulse_profiles.
+        The method check if the pulse is a delta pulse or a time-dependent pulse and appends it accordingly.
+
+        Parameters
+        ----------
+        t0 : float
+            Start time of the pulse
+        duration : float
+            Duration of the pulse
+        pulse_params : dict, optional
+            Dictionary of parameters for the pulse_shape functions, by default None.
+        """
+        if pulse_params is None:
+            pulse_params = self.pulse_params
+
+        if hasattr(self, "Rx"):
+            self.pulse_profiles.append(["delta_pulse", t0, None, pulse_params])
+        elif isinstance(self.h1, Qobj):
+            self.pulse_profiles.append(
+                ["pulse", np.linspace(t0, t0 + duration, self.time_steps), self.pulse_shape, pulse_params]
+            )
+        else:
+            self.pulse_profiles.append(
+                [
+                    [
+                        "pulse",
+                        np.linspace(t0, t0 + duration, self.time_steps),
+                        self.pulse_shape[i],
+                        pulse_params,
+                    ]
+                    for i in range(len(self.h1))
+                ]
+            )
