@@ -45,32 +45,28 @@ class NV(QSys):
         Microwave frequencies
     RF_freqs : numpy.ndarray
         RF frequencies
-    MW_H1 : Qobj
+    MW_h1 : Qobj
         Microwave Hamiltonian
-    RF_H1 : Qobj
+    RF_h1 : Qobj
         RF Hamiltonian
 
     Methods
     -------
     rho0_lowT
         Calculates the initial state of the system at low temperatures using the Boltzmann distribution
-    _set_MW_freqs
-        Sets the standard resonant microwave frequencies for the NV center corresponding to the electronic spin transitions
-    _set_RF_freqs
-        Sets the standard resonant RF frequencies for the NV center corresponding to the nuclear spin transitions
-    _set_MW_H1
-        Sets the standard microwave Hamiltonian for the NV center corresponding to the electronic spin transitions
-    _set_RF_H1
-        Sets the standard RF Hamiltonian for the NV center corresponding to the nuclear spin transitions
-    _ZeroField
+    _set_MW
+        Sets the standard microwave Hamiltonian and pulse frequencies for the NV center corresponding to the electronic spin transitions
+    _set_RF
+        Sets the standard RF Hamiltonian and pulse frequencies for the NV center corresponding to the nuclear spin transitions
+    zero_field
         Get the NV Hamiltonian term accounting for zero field splitting
-    _ElectronZeeman
+    electron_zeeman
         Get the NV hamiltonian term accounting for the electron Zeeman effect
-    _NuclearZeeman
+    nuclear_zeeman
         Get the NV hamiltonian term accounting for the nuclear (Nitrogen) Zeeman effect
-    _HyperfineN
+    hyperfine_N
         Get the NV hamiltonian term accounting for the hyperfine coupling with Nitrogen
-    _Quadrupole
+    quadrupole
         Get the quadrupole term
     add_spin
         Adds an extra spin to the NV system
@@ -167,23 +163,23 @@ class NV(QSys):
 
         # calculates the Hamiltonian for the given field and nitrogen isotope
         if N == 15:
-            H0 = self._ZeroField() + self._ElectronZeeman() + self._HyperfineN() + self._NuclearZeeman()
+            H0 = self.zero_field() + self.electron_zeeman() + self.hyperfine_N() + self.nuclear_zeeman()
             rho0 = tensor(fock_dm(3, 1), qeye(2)).unit()
             observable = tensor(fock_dm(3, 1), qeye(2))
 
         elif N == 14:
             H0 = (
-                self._ZeroField()
-                + self._ElectronZeeman()
-                + self._HyperfineN()
-                + self._NuclearZeeman()
-                + self._Quadrupole()
+                self.zero_field()
+                + self.electron_zeeman()
+                + self.hyperfine_N()
+                + self.nuclear_zeeman()
+                + self.quadrupole()
             )
             rho0 = tensor(fock_dm(3, 1), qeye(3)).unit()
             observable = tensor(fock_dm(3, 1), qeye(3))
 
         elif N == 0 or N is None:
-            H0 = self._ZeroField() + self._ElectronZeeman()
+            H0 = self.zero_field() + self.electron_zeeman()
             rho0 = basis(3, 1)
             observable = fock_dm(3, 1)
 
@@ -195,10 +191,8 @@ class NV(QSys):
         if temp is not None:
             self.rho0_lowT(temp, units_temp)
 
-        self._set_MW_freqs()
-        self._set_RF_freqs()
-        self._set_MW_H1()
-        self._set_RF_H1()
+        self._set_MW()
+        self._set_RF()
 
     def rho0_lowT(self, temp, units_temp="K"):
         """
@@ -298,36 +292,77 @@ class NV(QSys):
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _set_MW_freqs(self):
+    def _set_MW(self):
         """
-        Sets the standard resonant microwave frequencies for the NV center corresponding to the electronic spin transitions.
+        Sets the standard microwave Hamiltonian for the NV center corresponding to the electronic spin transitions.
+        Sets the corresponding frequencies for microwave pulses with the transitions corresponding to the energy levels.
         """
+        Rx_0 = Qobj([[1, 0, 0], [0, 0, 1], [0, 1, 0]])
+        Rx_1 = Qobj([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
+        Ry_0 = Qobj([[1, 0, 0], [0, 0, -1j], [0, 1j, 0]])
+        Ry_1 = Qobj([[0, -1j, 0], [1j, 0, 0], [0, 0, 1]])
+
         if self.N == 15:
+            self.MW_h1 = tensor(jmat(1, "x"), qeye(2)) * 2**0.5
+            self.MW_Rx = [tensor(Rx_0, qeye(2)), tensor(Rx_1, qeye(2))]
+            self.MW_Ry = [tensor(Ry_0, qeye(2)), tensor(Ry_1, qeye(2))]
+
             f1 = (np.sum(self.energy_levels[2:4]) - np.sum(self.energy_levels[1:2])) / 2
             f2 = (np.sum(self.energy_levels[4:6]) - np.sum(self.energy_levels[1:2])) / 2
             self.MW_freqs = np.array([f1, f2])
+
         elif self.N == 14:
+            self.MW_h1 = tensor(jmat(1, "x"), qeye(3)) * 2**0.5
+            self.MW_Rx = [tensor(Rx_0, qeye(3)), tensor(Rx_1, qeye(3))]
+            self.MW_Ry = [tensor(Ry_0, qeye(3)), tensor(Ry_1, qeye(3))]
+
             f1 = (np.sum(self.energy_levels[3:6]) - np.sum(self.energy_levels[1:3])) / 3
             f2 = (np.sum(self.energy_levels[6:9]) - np.sum(self.energy_levels[1:3])) / 3
             self.MW_freqs = np.array([f1, f2])
+
         elif self.N == 0 or self.N is None:
+            self.MW_h1 = tensor(jmat(1, "x")) * 2**0.5
+            self.MW_Rx = [Rx_0, Rx_1]
+            self.MW_Ry = [Ry_0, Ry_1]
+
             f1 = self.energy_levels[1]
             f2 = self.energy_levels[2]
             self.MW_freqs = np.array([f1, f2])
+
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _set_RF_freqs(self):
+    def _set_RF(self):
         """
-        Sets the standard resonant RF frequencies for the NV center corresponding to the nuclear spin transitions.
+        Sets the standard RF Hamiltonian for the NV center corresponding to the nuclear spin transitions.
+        Sets the corresponding frequencies for RF pulses with the transitions corresponding to the energy levels.
         """
+        Rx_0 = Qobj([[1, 0, 0], [0, 0, 1], [0, 1, 0]])
+        Rx_1 = Qobj([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
+        Ry_0 = Qobj([[1, 0, 0], [0, 0, -1j], [0, 1j, 0]])
+        Ry_1 = Qobj([[0, -1j, 0], [1j, 0, 0], [0, 0, 1]])
+
         if self.N == 15:
+            self.RF_h1 = tensor(qeye(3), jmat(1 / 2, "x")) * 2
+            self.RF_Rx = self.RF_h1.copy()
+            self.RF_Ry = tensor(qeye(3), jmat(1 / 2, "y")) * 2
+
             f1 = self.energy_levels[1]
             f2 = self.energy_levels[3] - self.energy_levels[2]
             f3 = self.energy_levels[5] - self.energy_levels[4]
             self.RF_freqs = np.array([f1, f2, f3])
-        # for the 14N isotope, the RF frequencies are more complicated as they need to respect the selection rule of Delta mI = +-1
+
         elif self.N == 14:
+            self.RF_h1 = tensor(qeye(3), jmat(1, "x")) * 2**0.5
+
+            Rx_0 = Qobj([[1, 0, 0], [0, 0, 1], [0, 1, 0]])
+            Rx_1 = Qobj([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
+            Ry_0 = Qobj([[1, 0, 0], [0, 0, -1j], [0, 1j, 0]])
+            Ry_1 = Qobj([[0, -1j, 0], [1j, 0, 0], [0, 0, 1]])
+            self.RF_Rx = [tensor(qeye(3), Rx_0), tensor(qeye(3), Rx_1)]
+            self.RF_Ry = [tensor(qeye(3), Ry_0), tensor(qeye(3), Ry_1)]
+
+            # for the 14N isotope, the RF frequencies are more complicated as they need to respect the selection rule of Delta mI = +-1
             # the order of the ms states changes above the GSLAC
             if self.B0 <= 102.5:
                 f1 = self.energy_levels[2] - self.energy_levels[1]  # 0 -> -1 at ms=0
@@ -345,38 +380,16 @@ class NV(QSys):
                 f6 = self.energy_levels[8] - self.energy_levels[6]  # 0 -> +1 at ms=-1
 
             self.RF_freqs = np.array([f1, f2, f3, f4, f5, f6])
+
         elif self.N == 0 or self.N is None:
-            self.RF_freqs = None
+            self.RF_h1 = qeye(3)
+            self.RF_Rx = qeye(3)
+            self.RF_Ry = qeye(3)
+
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _set_MW_H1(self):
-        """
-        Sets the standard microwave Hamiltonian for the NV center corresponding to the electronic spin transitions.
-        """
-        if self.N == 15:
-            self.MW_H1 = tensor(jmat(1, "x"), qeye(2)) * 2**0.5
-        elif self.N == 14:
-            self.MW_H1 = tensor(jmat(1, "x"), qeye(3)) * 2**0.5
-        elif self.N == 0 or self.N is None:
-            self.MW_H1 = tensor(jmat(1, "x")) * 2**0.5
-        else:
-            raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
-
-    def _set_RF_H1(self):
-        """
-        Sets the standard RF Hamiltonian for the NV center corresponding to the nuclear spin transitions.
-        """
-        if self.N == 15:
-            self.RF_H1 = tensor(qeye(3), jmat(1 / 2, "x")) * 2
-        elif self.N == 14:
-            self.RF_H1 = tensor(qeye(3), jmat(1, "x")) * 2**0.5
-        elif self.N == 0 or self.N is None:
-            self.RF_H1 = qeye(3)
-        else:
-            raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
-
-    def _ZeroField(self):
+    def zero_field(self):
         """Get the NV Hamiltonian term accounting for zero field splitting.
 
         Parameters
@@ -403,7 +416,7 @@ class NV(QSys):
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _ElectronZeeman(self):
+    def electron_zeeman(self):
         """
         Get the NV hamiltonian term accounting for the electron Zeeman effect.
 
@@ -447,7 +460,7 @@ class NV(QSys):
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _NuclearZeeman(self):
+    def nuclear_zeeman(self):
         """
         Get the NV hamiltonian term accounting for the nuclear (Nitrogen) Zeeman effect.
 
@@ -483,7 +496,7 @@ class NV(QSys):
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _HyperfineN(self):
+    def hyperfine_N(self):
         """
         Get the NV hamiltonian term accounting for the hyperfine coupling with Nitrogen.
 
@@ -504,13 +517,13 @@ class NV(QSys):
         else:
             raise ValueError(f"Invalid value for Nitrogen. Expected either 14 or 15, got {self.N}.")
 
-    def _Quadrupole(self):
+    def quadrupole(self):
         """
         Get the quadrupole term
 
         Returns
         -------
-        Quadrupole Hamiltonian : Qobj
+        quadrupole Hamiltonian : Qobj
         """
         if self.N == 14:
             return -5.01 * tensor(qeye(3), jmat(1, "z") ** 2)
@@ -523,7 +536,7 @@ class NV(QSys):
 
     def add_spin(self, H_spin):
         """
-        Overwrites the parent class method by calling it and updating MW_H1 and RF_H1 attributes
+        Overwrites the parent class method by calling it and updating MW_h1 and RF_h1 attributes
 
         Parameters
         ----------
@@ -532,12 +545,12 @@ class NV(QSys):
         """
         super().add_spin(H_spin)
 
-        self.MW_H1 = tensor(self.MW_H1, qeye(self.dim_add_spin))
-        self.RF_H1 = tensor(self.RF_H1, qeye(self.dim_add_spin))
+        self.MW_h1 = tensor(self.MW_h1, qeye(self.dim_add_spin))
+        self.RF_h1 = tensor(self.RF_h1, qeye(self.dim_add_spin))
 
     def truncate(self, mS=None, mI=None):
         """
-        Overwrites the parent class method by calling it and updating MW_H1 and RF_H1 attributes.
+        Overwrites the parent class method by calling it and updating MW_h1 and RF_h1 attributes.
         The indexes to be removed are calculated according to the mS and mI parameters.
 
         Parameters
@@ -599,13 +612,13 @@ class NV(QSys):
         indexes = sorted(set(indexes))
         super().truncate(indexes)
 
-        self.MW_H1 = Qobj(np.delete(np.delete(self.MW_H1.full(), indexes, axis=0), indexes, axis=1))
-        self.RF_H1 = Qobj(np.delete(np.delete(self.RF_H1.full(), indexes, axis=0), indexes, axis=1))
+        self.MW_h1 = Qobj(np.delete(np.delete(self.MW_h1.full(), indexes, axis=0), indexes, axis=1))
+        self.RF_h1 = Qobj(np.delete(np.delete(self.RF_h1.full(), indexes, axis=0), indexes, axis=1))
 
         # corrrect the dimensions of the objects
         self.H0.dims = [dims, dims]
-        self.MW_H1.dims = [dims, dims]
-        self.RF_H1.dims = [dims, dims]
+        self.MW_h1.dims = [dims, dims]
+        self.RF_h1.dims = [dims, dims]
 
         if self.observable is not None:
             if isinstance(self.observable, Qobj):
